@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -42,7 +42,13 @@ RenameCategory KDebugSettingsUtil::parseRenameCategory(QString line, const QStri
     const int space = line.indexOf(QLatin1Char(' '));
     if (space == -1) {
         qCWarning(KDEBUGSETTINGS_LOG) << "Invalid categories file. Missing space. Syntax is logname<space>description + optional element. Line: "
-                                      << line << " from file:" << filename << endl;
+                                      << line << " from file:" << filename
+                                 #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+                                      << endl
+                                 #else
+                                      << Qt::endl
+                                 #endif
+                                         ;
         return category;
     }
 
@@ -92,7 +98,13 @@ KdeLoggingCategory KDebugSettingsUtil::parseLineKdeLoggingCategory(QString line,
     const int space = line.indexOf(QLatin1Char(' '));
     if (space == -1) {
         qCWarning(KDEBUGSETTINGS_LOG) << "Invalid categories file. Missing space. Syntax is logname<space>description + optional element. Line: "
-                                      << line << " from file:" << filename << endl;
+                                      << line << " from file:" << filename
+                                 #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+                                      << endl
+                                 #else
+                                      << Qt::endl
+                                 #endif
+                                         ;
         return category;
     }
     QString logName;
